==> pegasus-merchandise-api-1.4.29-sources.jar: com/thebeastshop/pegasus/merchandise/cond/PcsCopywriterCond.java <==
package com.thebeastshop.pegasus.merchandise.cond;

import com.thebeastshop.pegasus.util.cond.BaseQueryCond;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by QTJ on 2017/6/12.
 */
public class PcsCopywriterCond extends BaseQueryCond implements Serializable {

    private Long id;

    private String code;

    private String content;

    private Integer validStatus;

    private Integer active;

    private Date validStartTime;

    private Date validEndTime;

    private Long createId;

    private Date createTime;

    private Date updateTime;

    private String productName;

    private String productCode;



    public PcsCopywriterCond(String code) {
        this.code = code;
    }

    public PcsCopywriterCond() {
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public Integer getActive() {
        return active;
    }

    public void setActive(Integer active) {
        this.active = active;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public Integer getValidStatus() {
        return validStatus;
    }

    public void setValidStatus(Integer validStatus) {
        this.validStatus = validStatus;
    }

    public Date getValidStartTime() {
        return validStartTime;
    }

    public void setValidStartTime(Date validStartTime) {
        this.validStartTime = validStartTime;
    }

    public Date getValidEndTime() {
        return validEndTime;
    }

    public void setValidEndTime(Date validEndTime) {
        this.validEndTime = validEndTime;
    }

    public Long getCreateId() {
        return createId;
    }

    public void setCreateId(Long createId) {
        this.createId = createId;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    @Override
    public String toString() {
        return "PcsCopywriterCond{" +
                "id=" + id +
                ", code='" + code + '\'' +
                ", content='" + content + '\'' +
                ", validStatus=" + validStatus +
                ", active=" + active +
                ", validStartTime=" + validStartTime +
                ", validEndTime=" + validEndTime +
                ", createId=" + createId +
                ", createTime=" + createTime +
                ", updateTime=" + updateTime +
                ", productName='" + productName + '\'' +
                ", productCode='" + productCode + '\'' +
                '}';
    }
}

==> pegasus-merchandise-api-3.1.0-sources.jar: com/thebeastshop/pegasus/merchandise/cond/PcsCopywriterCond.java <==
package com.thebeastshop.pegasus.merchandise.cond;

import com.thebeastshop.common.BaseQueryCond;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by QTJ on 2017/6/12.
 */
public class PcsCopywriterCond extends BaseQueryCond implements Serializable {

    private Long id;

    private String code;

    private String content;

    private Integer validStatus;

    private Integer active;

    private Date validStartTime;

    private Date validEndTime;

    private Long createId;

    private Date createTime;

    private Date updateTime;

    private String productName;

    private String productCode;



    public PcsCopywriterCond(String code) {
        this.code = code;
    }

    public PcsCopywriterCond() {
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public Integer getActive() {
        return active;
    }

    public void setActive(Integer active) {
        this.active = active;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public Integer getValidStatus() {
        return validStatus;
    }

    public void setValidStatus(Integer validStatus) {
        this.validStatus = validStatus;
    }

    public Date getValidStartTime() {
        return validStartTime;
    }

    public void setValidStartTime(Date validStartTime) {
        this.validStartTime = validStartTime;
    }

    public Date getValidEndTime() {
        return validEndTime;
    }

    public void setValidEndTime(Date validEndTime) {
        this.validEndTime = validEndTime;
    }

    public Long getCreateId() {
        return createId;
    }

    public void setCreateId(Long createId) {
        this.createId = createId;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    @Override
    public String toString() {
        return "PcsCopywriterCond{" +
                "id=" + id +
                ", code='" + code + '\'' +
                ", content='" + content + '\'' +
                ", validStatus=" + validStatus +
                ", active=" + active +
                ", validStartTime=" + validStartTime +
                ", validEndTime=" + validEndTime +
                ", createId=" + createId +
                ", createTime=" + createTime +
                ", updateTime=" + updateTime +
                ", productName='" + productName + '\'' +
                ", productCode='" + productCode + '\'' +
                '}';
    }
}
